.. plone.restapi documentation master file, created by
   sphinx-quickstart on Mon Apr 28 13:04:12 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

========
REST API
========

A RESTful API for Plone.

.. toctree::
   :caption: Table of Contents
   :hidden:
   :maxdepth: 1

   introduction

.. toctree::
   :hidden:
   :maxdepth: 2

   authentication
   exploring
   content
   blocks
   history
   batching
   addons
   comments
   copymove
   expansion
   actions
   workflow
   workingcopy
   locking
   sharing
   registry
   types
   types-schema
   users
   groups
   principals
   roles
   breadcrumbs
   navigation
   contextnavigation
   serialization
   searching
   tusupload
   vocabularies
   controlpanels
   tiles
   querystring
   querystringsearch
   customization
   conventions
   translations
   email-send
   i18n
   email-notification
   upgrade-guide
   contributing
   system
   database

.. include:: ../../README.rst


Appendix, Indices and tables
----------------------------

.. toctree::

   http-status-codes
   glossary

* :ref:`genindex`

